import json
import redis

class Kyew(object):

    def __init__(self, r='redis://localhost:6379'):
        if isinstance(r, str):
            self.redis = redis.from_url(r)
        else:
            self.redis = r

    def pop_message(self, queue_name):
        message = self.redis.lpop(queue_name)
        return self._parse(message)

    def push_message(self, queue_name, message):
        if message == None:
            return None
        return self.redis.lpush(queue_name, self._dump(message))

    def _parse(_self, message):
        try:
            return json.loads(message)
        except TypeError:
            return message

    def _dump(_self, message):
        try:
            return json.dumps(message)
        except TypeError:
            return message



#!/usr/bin/env python
import os
import sys

from kyew import __version__

try:
    from setuptools import setup
    from setuptools.command.test import test as TestCommand

    class PyTest(TestCommand):
        def finalize_options(self):
            TestCommand.finalize_options(self)
            self.test_args = []
            self.test_suite = True

        def run_tests(self):
            # import here, because outside the eggs aren't loaded
            import pytest
            errno = pytest.main(self.test_args)
            sys.exit(errno)

except ImportError:

    from distutils.core import setup

    def PyTest(x):
        x

f = open(os.path.join(os.path.dirname(__file__), 'README.md'))
long_description = f.read()
f.close()

setup(
    name='kyew',
    version=__version__,
    description='Simple redis based queue protocol implementation',
    long_description=long_description,
    packages=['kyew',],
    license='MIT',
    author='Hugo Duksis',
    author_email='duksis@gmail.com',
    install_requires=[
        'redis',
    ],
    tests_require=[
        'mock',
        'pytest>=2.5.0',
        'fakeredis',
    ],
    cmdclass={'test': PyTest},
    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 3 - Alpha',

        # Indicate who your project is intended for
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',

        # Pick your license as you wish (should match "license" above)
        'License :: OSI Approved :: MIT License',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
)
